!!! warning "Rare Help for Users"
    There is **rare help** for users in this page. It is recommended to see [BESIII Data Reading](../user-manual/bes3-data-reading.md).

## besio

---
::: pybes3.besio.open
---
::: pybes3.besio.concatenate
---
::: pybes3.besio.open_raw
---

## root_io

::: pybes3.besio.root_io.get_top_type_name
---
::: pybes3.besio.root_io.get_vector_subtype
---
::: pybes3.besio.root_io.get_map_subtypes
---
::: pybes3.besio.root_io.recover_basic_element
---
::: pybes3.besio.root_io.recover_array_shape
---
::: pybes3.besio.root_io.tobjarray_np2ak
---
::: pybes3.besio.root_io.tobject_np2ak
---
::: pybes3.besio.root_io.stl_np2ak
---
::: pybes3.besio.root_io.get_symetric_matrix_idx
---
::: pybes3.besio.root_io.expand_zipped_symetric_matrix
---
::: pybes3.besio.root_io.expand_subbranch_symetric_matrix
---
::: pybes3.besio.root_io.process_digi_subbranch
---
::: pybes3.besio.root_io.process_evtrec_m_Evtx
---
::: pybes3.besio.root_io.process_evtrec_m_evtRecVeeVertexCol
---
::: pybes3.besio.root_io.process_dst_m_mdcTrackCol
---
::: pybes3.besio.root_io.process_dst_m_emcTrackCol
---
::: pybes3.besio.root_io.process_dst_m_extTrackCol
---
::: pybes3.besio.root_io.process_rec_m_recMdcTrackCol
---
::: pybes3.besio.root_io.process_rec_m_recEmcShowerCol
---
::: pybes3.besio.root_io.process_rec_m_recMdcKalTrackCol
---
::: pybes3.besio.root_io.preprocess_subbranch
---
::: pybes3.besio.root_io.BesInterpretation
---
::: pybes3.besio.root_io.bes_interpretation_of
---
::: pybes3.besio.root_io.wrap_uproot_interpretation
---
::: pybes3.besio.root_io.wrap_uproot_TBranchElement_branches
---
::: pybes3.besio.root_io.wrap_uproot
---

## raw_io

::: pybes3.besio.raw_io.BesFlag
---
::: pybes3.besio.raw_io._raw_dict_to_ak
---
::: pybes3.besio.raw_io.RawBinaryReader
---
::: pybes3.besio.raw_io._is_raw
---
::: pybes3.besio.raw_io.concatenate
---
